function bwavesc(fin,str)

%   Calculate dispersion curves for barotropic waves over topography. 
%   Includes mean flow or friction. Works for any complex frequency outside
%       the continuum.
%
%   call as
%       bwavesc(fin,str)
%   where
%       fin             = an input array developed by bwavescsetup.m or
%                                       bwavescfinch.m
%       str  (string)   = title of output file
%   All units cgs

%   K. Brink  2/25/2020  3/8/2020 3/16/2020  3/18/2020

clear global
global f h hx z ncal rl del dx g r v vx vxx icbc iobc

g = 980;
maxit = 150;



nn = fin(1);                            % number of x grid points

xmax = fin(2);                          % domain width (km);
xmax = xmax*1e5;

acc = fin(3);                           % nominal fractional accuracy

del = fin(4);                           % = 1 for free surface, 0 for rigid lid

icbc = fin(5);                          % = 0 for closed boundary at x = 0, 1 for open

iobc = fin(6);                          % = 0 for closed boundary condition at x = x_Max, 1 for open

f = fin(7);                             % Coriolis parameter (1/sec)

nw = fin(8);                            % Maximum number of frequencies on the dispersion curve

rlz = fin(9);                          % first wavenumber on the dispersion curve (1/cm)

drl = fin(10);                          % wavenumber increment along dispersion curve (1/cm)

wgr = fin(11);                          % Guess at real part of frequency for the first point on the dispersion curve (1/sec)
wgi = fin(12);                          % Guess at imaginary part of frequency

nd = fin(13);                           % number of (x, depth) pairs
nhigh = 13 + nd;

xh = fin(14:nhigh);                     % array of x locations for depth values (cm);
xh = xh*1e5;

hh = fin(nhigh+1:nhigh + nd);           % array of water depths (m)
hh = hh*100;


nlowv = nhigh + nd +1;
nv = fin(nlowv);                        % number of (x,vbar) pairs to read

if nv > 0.5
    nhigh = nlowv + nv;

    xvv = fin(nlowv+1:nhigh);           % array of x locations for vbar (km)
    xvv = xvv*1e5;

    vbarv = fin(nhigh+1:nhigh +nv);     % array of vbar  (cm/sec)
else
   xvv = [];
   vbarv = [];
   nhigh = nlowv;
end


nlowr = nhigh + 1 + nv;     
nr = fin(nlowr);                         % number of (x,r) pairs to read

if nr > 0.5

    nhigh = nlowr+nr;   
    xrr = fin(nlowr+1:nhigh);           % array of x values for r (km)
    xrr = xrr*1e5;

    rrr = fin(nhigh+1:nhigh+nr);        % array of bottom friction coefficients r (cm/sec)
else
    xrr = [];
    rrr = [];
end


disp(['f = ' num2str(f) ' 1/sec'])
if del < 0.5
    disp('Rigid lid')
    del = 0;
else
    disp('Free surface')
    del = 1;
end

if icbc < 0.5
    disp('Closed boundary at x = 0')
    icbc = 0;
else
    disp('Open boundary at x = 0')
    icbc = 1;
end

if iobc < 0.5
    disp('Closed boundary at x = x_Max')
    iobc = 0;
else
    disp('Open boundary at x = x_Max')
    iobc = 1;
end

disp([int2str(nn) ' grid points in x'])


dx = xmax/(nn-1);
x = dx*(0:(nn-1));
rl = rlz + (0:(nw-1))*drl;

ws = NaN*rl*(1 + 1i);        %   array of final frequencies
wg = wgr + 1i*wgi;


ierd = bwavescdep(xh,hh,x);
hmax = max(h);
xf = [0 x 0]/1e5;
yf = [-hmax -h -hmax]/100;

ierv = bwavescvel(xvv,vbarv,x);

ierf = bwavescr(xrr,rrr,x,str);

ierr = ierd + ierv + ierf;
if ierr > 0
    nw = 0;
end



ncal = 1;
disp(' ')
while ncal <= nw
    disp(' ')
    disp(' ')
    epw = acc*abs(wg);
    
    wga = [real(wg) imag(wg)];
    [www,rni,exitflag] = fminsearch(@bwavesccal,wga, optimset('TolX',epw,'MaxIter',maxit));     
    
    if exitflag > 0.5
        % success
        
        wwwc = www(1) + 1i*www(2);
        ws(ncal) = wwwc;
        
        
        pp = bwavescsol(wwwc);
        
        ps = pp(1);
        pp = pp/ps;
        rint = h.*abs(pp).^2;
        rnorm = dx*(sum(rint) - rint(1)/2 - rint(end)/2);
        pp = pp/sqrt(rnorm);
        
        if abs(imag(wwwc)/real(wwwc)) < acc && nv > 0.5
            wwpc = real(wwwc) + rl(ncal)*v;
            wwmax = max(wwpc);
            wwmin = min(wwpc);
            if (wwmin/wwmax) < 0
                disp(' ')
                disp('Warning: critical layer with real frequency!')
                disp(' ')
            end
        end
        
        
        disp(' ')
        disp(['rl (cm^-1), w (complex: sec^-1) = ' num2str(rl(ncal)) ',  ' num2str(wwwc) ])
        
        
        if nw > 1.5
                figure(3)
                clf
                plot(rl,real(ws),'k',rl,imag(ws),'--',rl,0*rl,'k')
                title(['Dispersion curve for case ' str])
                xlabel('l [1/cm]')
                ylabel('\omega [1/sec]')
        end
        
        bwavescpl(x,pp,nv,nr,wwwc,str)
        
      
        if ncal == 1;
            cp = wwwc/rl(ncal);
            wg = wwwc + drl*cp;
            % wg = www;             %   to guess cg = 0;
        else
            cg = (ws(ncal) - ws(ncal-1))/drl;
            wg = wwwc + drl*cg;
        end
        
        ncal = ncal + 1;
        
        
    elseif exitflag < -0.5
        disp('Failed')
        ncal = nw+1;
    else
        disp(['Failed: used up ' int2str(maxit) ' iterations'])
        ncal = nw+1;
    end
    % pause   
end

 if nw > 1.5
                figure(3)
                clf
            
                plot(rl,real(ws),'k',rl,imag(ws),'k--',rl,0*rl,'k')
                title(['Dispersion curve for case ' str ' (imaginary part dashed)'])
                xlabel('l [1/cm]')
                ylabel('\omega [1/sec]')
        end



disp(' ')
iss = input('Do you want to save this curve? yes = 1, no = 0 ');
if iss > 0.5
    
    
    estr = ['save ' str '.mat rl ws x h v r pp f del '];
    eval(estr)
    disp(['Saved as ' str '.mat'])
    disp('File includes complex dispersion curve, x, h, vbar, r, pressure (last frequency only),')
    disp('                       f, and del')
end
