function filein = bwavescsetup

%   Create an input array for "bwavesp.m", given answers to queries
%   DFor use with bwavesc: complex omega   
%
%   Call as
%       filein = bwavescsetup
%   In response to queries, you can enter either numbers or array names

%   K.H. Brink
%       5/18/2003, 1/1/2005, 3/30/2012, 5/22/2018  3/8/2020 3/16/2020
%       3/18/2020

disp(' ')
disp('     Barotropic coastal-trapped waves with complex frequency')
disp(' ')
disp('This mfile will ask you a sequence of questions ')
disp('     that are used to build the input array.     ')
disp(' ')
    

filein(1) = input('How many total gridpoints do you want in the cross shelf direction? (nn) ');
if filein < 3
    disp(' ')
    disp('Error! Want to have nn > 2')
end
xmax = input('Enter the domain width (W) (km) ');
filein(2) = xmax;
filein(3) = input('Enter the nominal fractional accuracy for the solution (acc) ');
filein(4) = input('Enter 0 for a rigid lid, 1 for a free surface (del) ');
filein(5) = input('Enter 0 for closed boundary at x = 0, 1 for open boundary (icbc) ');
filein(6) = input('Enter 0 for closed boundary at x = x_max, 1 for open boundary (iobc) ');
filein(7) = input('Enter the Coriolis parameter (f) (1/sec) ');
filein(8) = input('Enter the number of frequencies to be computed (nw) ');

filein(9) = input('Enter the first alongshore wavenumber to use (rlz) (1/cm) ');
if filein(8) <= 1.1
    filein(10) = filein(9);
else
    filein(10) = input('Enter the wavenumber increment to use after rlz (drl) (1/cm) ');
end

filein(11) = input('First guess at real part of frequency (1/sec)? ');
filein(12) = input('First guess at imaginary part of frequency (1/sec)? ');



%   Read in depth
filein(13) = input('How many distance, depth pairs will you provide (ndep >=1) ');
ndep = filein(13);
xdep = input('Array of offshore distances for depth values (xdep in km) (dimension ndep) ');
%   First value of xdep must be 0!
[n,m] = size(xdep);
if n > m
    xdep = xdep';
end
if length(xdep) ~= ndep
    disp(' ')
    disp(' Error! Array size for xdep must match given dimension!')
    disp(' ')
end


filein = [filein xdep];
depr = input('Array of depths corresponding to xdep (depr in m) ');
if n > m
    depr = depr';
end

if length(depr) ~= ndep
    disp(' ')
    disp(' Error! Array size for depth must match given dimension!')
    disp(' ')
end

nddd = max([n m]);
filein = [filein depr];
if xmax > xdep(end)
    xdep = [xdep xmax];
    depr = [depr depr(nddd)];
end

iqq = find(depr < 0);
if isempty(iqq) == 0
    disp(' ')
    disp('Error: All depths must be > 0!')
end


%       Read in mean velocity

nv = input('How many distance, mean v pairs will you provide (nv >= 0 ) ');
filein = [filein nv];
if nv > 0.5
    xv = input('Array of offshore distances for mean flow values (xv in km) (dimension nv) ');
    

    [n,m] = size(xv);
    if n > m
        xv = xv';
    end
    if length(xv) ~= nv
        disp(' ')
        disp(' Error! Array size for xv must match given dimension!')
        disp(' ')
    end
    

    vbar = input('Array of mean velocities corresponding to xv (vbar in cm/sec) ');
    [n,m] = size(vbar);
    if n > m
        vbar = vbar';
    end
    
    if length(vbar) ~= nv
        disp(' ')
        disp(' Error! Array size for vbar must match given dimension!')
        disp(' ')
    end
    
    
    nddd = max([n m]);
    
    
    
    filein = [filein xv vbar];
end


%       Read in bottom friction
nr = input('Number of distance, bottom friction pairs to read (nr) ');
filein = [filein nr];
if nr > 0.05
    xr = input('Offshore distances for bottom friction values (xr in km) ');
    %   First value of xr must be 0!
    rr = input('Array of bottom friction values corresponding to xr (rr in cm/sec) ');
    [n, m] = size(xr);
    nrr = max([n m]);
    if n > m
        xr = xr';
        rr = rr';
    end
    
    
    if length(xr) ~= nr 
        disp(' ')
        disp(' Error! Array size for xr must match given dimension!')
        disp(' ')
    end
    
    if length(rr) ~= nr
        disp(' ')
        disp(' Error! Array size for r must match given dimension!')
        disp(' ')
    end
    filein = [filein xr rr];
else
   rr = [];
   xr = [];
end

%  This completes the input array


%   Plot out results so the user can see if they look right
    
figure(8)
clf
subplot(3,1,1)
if sum(rr) > 1e-10
    xr = [xr xmax];
    rr = [rr rr(end)];
    rmax = max(rr);
    plot(xr,rr)
else
    rmax = 0.7;
    plot(xdep,0*xdep)
    hold on
        text(xmax/2,0.5,'r = 0')
    hold off
end


axis([0 xmax 0 1.5*rmax])  
title('Bottom friction parameter [cm/sec]')
ylabel('r [cm/sec]')

subplot(3,1,2)

if nv > 0.5
    plot(xv,vbar)
    vmax = max(vbar);
    vmin = min(vbar);
else
       
    text(0.5*xmax,0.5,'vbar = 0')
    
    vmax = 0.75;
    vmin = 0;
end
title('Mean Velocity [cm/sec]')
ylabel('v [cm/sec]')
axis([0 xmax 1.5*vmin 1.5*vmax])

subplot(3,1,3)
xtt = xdep;
dtt = depr;
if xdep(1) > 0
    xtt = [0 xdep];
    dtt = [depr(1) depr];
end
if depr(end) < xmax
    xtt = [xtt xmax];
    dtt = [dtt dtt(end)];
end

zmax = max(dtt);
xxx = [xtt max(xtt) 0];
yyy = -[dtt zmax zmax];

fill(xxx,yyy,'b')

axis([0 xmax -zmax 0])
title('Depth')
ylabel('Depth [m]')
xlabel('Offshore distance [km]')
set(gca,'TickDir','out')



%   Check on overall file size

fin = filein;
    
    
    ncheck = 13 +2*ndep + 1 + 2*nv + 1 + 2*nr;
    if length(fin) ~= ncheck
        disp(' ')
        disp('Problem! length is not right!')
        
        disp(' ')
    end
